from pathlib import Path

SCREENSHOTS_PATH = Path("{{ screenshots_path }}")
IMAGES_PATH = Path("{{ images_path }}")
SCREEN_RESOLUTION = ("{{ screen_width }}", "{{ screen_height }}")

OCR_LANGUAGE = "{{ ocr_language }}"
PYTESSERACT_PATH = "{{ pytesseract_path }}"
